@@ -14,9 +14,10 @@ from django.utils.html import strip_tags
 from django.utils.translation import ugettext_lazy as _
 from django.conf import settings
 
+from common.fields import AutoOneToOneField, JSONField
+
 from pybb.markups import mypostmarkup
-from pybb.fields import AutoOneToOneField, JSONField
-from pybb.util import urlize, memoize_method, unescape
+from pybb.util import urlize, unescape
 
 
 TZ_CHOICES = [(float(x[0]), x[1]) for x in (
@@ -68,7 +69,7 @@ class Forum(models.Model):
     position = models.IntegerField(_('Position'), blank=True, default=0)
     description = models.TextField(_('Description'), blank=True)
     moderators = models.ManyToManyField(User, blank=True, null=True, verbose_name=_('Moderators'))
-    updated = models.DateTimeField(_('Updated'), null=True)
+    updated = models.DateTimeField(_('Updated'), blank=True, null=True)
     post_count = models.IntegerField(_('Post count'), blank=True, default=0)
     topic_count = models.IntegerField(_('Topic count'), blank=True, default=0)
 
@@ -264,7 +265,7 @@ class Profile(models.Model):
         return False
 
     def get_absolute_url(self):
-        return reverse('pybb_profile', args=[self.user.username])
+        return reverse('pybb_user', args=[self.user.username])
 
 
 class Attachment(models.Model):
