@@ -8,7 +8,6 @@ PYBB_NOTICE = ''
 PYBB_TOPIC_PAGE_SIZE = 10
 PYBB_FORUM_PAGE_SIZE = 20
 PYBB_USERS_PAGE_SIZE = 20
-PYBB_HOST = 'hey.fix.your.settings'
 PYBB_AVATAR_WIDTH = 60
 PYBB_AVATAR_HEIGHT = 60
 PYBB_DEFAULT_TIME_ZONE = 3
@@ -17,11 +16,11 @@ PYBB_SIGNATURE_MAX_LINES = 3
 PYBB_QUICK_TOPICS_NUMBER = 10
 PYBB_QUICK_POSTS_NUMBER = 10
 PYBB_READ_TIMEOUT = 3600 * 24 * 7 # seconds
-PYBB_POST_AUTOJOIN_TIMEOUT = 60 # minutes
+PYBB_POST_AUTOJOIN_ENABLED = True
+PYBB_POST_AUTOJOIN_TIMEOUT = 60 * 60 # seconds
 PYBB_DEFAULT_MARKUP = 'bbcode'
 PYBB_FREEZE_FIRST_POST = True
 PYBB_ADMIN_URL = '/admin/'
-PYBB_EMAIL_DEBUG = False
 PYBB_ATTACHMENT_SIZE_LIMIT = 1024 * 1024
 PYBB_ATTACHMENT_ENABLE = True
 PYBB_SKIN = 'default'
