@@ -3,8 +3,7 @@ from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.utils.translation import ugettext as _
 from django.utils import translation
-
-from pybb.util import absolute_url
+from django.contrib.sites.models import Site
 
 
 TOPIC_SUBSCRIPTION_TEXT_TEMPLATE = lambda: _(u"""New reply from %(username)s to topic that you have subscribed on.
@@ -15,24 +14,16 @@ See topic: %(post_url)s
 Unsubscribe %(unsubscribe_url)s""")
 
 
-def send_mail(rec_list, subject, text, html=None):
+def send_mail(recipients, subject, text, html=None):
     """
     Shortcut for sending email.
     """
 
-    from_email = settings.DEFAULT_FROM_EMAIL
-
-    msg = EmailMultiAlternatives(subject, text, from_email, rec_list)
+    msg = EmailMultiAlternatives(subject, text, settings.DEFAULT_FROM_EMAIL,
+                                 recipients)
     if html:
         msg.attach_alternative(html, "text/html")
-    if settings.PYBB_EMAIL_DEBUG:
-        logging.debug('---begin---')
-        logging.debug('To: %s' % rec_list)
-        logging.debug('Subject: %s' % subject)
-        logging.debug('Body: %s' % text)
-        logging.debug('---end---')
-    else:
-        msg.send(fail_silently=True)
+    msg.send(fail_silently=True)
 
 
 def notify_topic_subscribers(post):
@@ -51,11 +42,13 @@ def notify_topic_subscribers(post):
 
                 subject = u'RE: %s' % topic.name
                 to_email = user.email
+                hostname = Sites.objects.get_current().domain
+                delete_url = reverse('pybb_delete_subscription', args=[post.topic.id])
                 text_content = TOPIC_SUBSCRIPTION_TEXT_TEMPLATE() % {
                     'username': post.user.username,
                     'message': post.body_text,
-                    'post_url': absolute_url(post.get_absolute_url()),
-                    'unsubscribe_url': absolute_url(reverse('pybb_delete_subscription', args=[post.topic.id])),
+                    'post_url': 'http://%s%s' % (hostname, post.get_absolute_url()),
+                    'unsubscribe_url': 'http://%s%s' % (hostname, delete_url),
                 }
                 #html_content = html_version(post)
                 send_mail([to_email], subject, text_content)
