@@ -9,8 +9,7 @@ try:
 except ImportError:
     pytils_enabled = False
 
-from django.shortcuts import get_object_or_404, get_list_or_404, render_to_response
-from django.template import RequestContext
+from django.shortcuts import get_object_or_404, get_list_or_404
 from django.http import HttpResponseRedirect, HttpResponse,\
                         HttpResponseNotFound, Http404
 from django.contrib.auth.models import User
@@ -19,11 +18,12 @@ from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.db import connection
 from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext
+
+from common.decorators import render_to, ajax
 
 from pybb.markups import mypostmarkup
 from pybb.util import quote_text, paginate,\
-                        set_language, ajax, urlize
+                        set_language, urlize
 from pybb.models import Category, Forum, Topic, Post, Profile, \
                         Attachment, MARKUP_CHOICES
 from pybb.forms import  AddPostForm, EditPostForm, EditHeadPostForm, \
@@ -32,24 +32,6 @@ from pybb.orm import load_related
 from pybb.read_tracking import update_read_tracking
 
 
-def render_to(template, func):
-    """
-    Shortcut for rendering template with RequestContext.
-
-    If decorated function returns non dict then just return that result
-    else use RequestContext for rendering the template.
-    """
-
-    def wrapper(request, *args, **kwargs):
-        output = func(request, *args, **kwargs)
-        if not isinstance(output, dict):
-            return output
-        else:
-            return render_to_response(template, output,
-                                      context_instance=RequestContext(request))
-    return wrapper
-
-
 def index_ctx(request):
     cats = {}
     for forum in Forum.objects.all().select_related():
@@ -159,35 +141,6 @@ def add_post_ctx(request, forum_id, topic_id):
     else:
         form = AddPostForm(**form_kwargs)
 
-    if topic and form.is_valid():
-        last_post = topic.last_post
-        delta = (datetime.now() - last_post.created)
-        time_diff = delta.seconds / 60
-        timeout = settings.PYBB_POST_AUTOJOIN_TIMEOUT
-        
-        # TODO: Move to formmmmm
-        if (last_post.user == request.user and
-            not delta.days and time_diff < timeout):
-            if settings.LANGUAGE_CODE.startswith('ru') and pytils_enabled:
-                join_message = u"Добавлено спустя %s %s" % (time_diff,
-                                    pytils.numeral.choose_plural(time_diff,
-                                    (u"минуту", u"минуты", u"минут")))
-            else:
-                join_message = ungettext(u"Added after %s minute",
-                                         u"Added after %s minutes",
-                                         time_diff) % time_diff
-
-            if last_post.markup == "bbcode":
-                join_message = "[b]%s[/b]" % join_message
-            elif last_post.markup == "markdown":
-                join_message = "**%s**" % join_message
-
-            last_post.body += u"\n\n%s:\n\n%s" % (join_message,
-                                                form.cleaned_data["body"])
-            last_post.updated = datetime.now()
-            last_post.save()
-            return HttpResponseRedirect(last_post.get_absolute_url())
-
     if form.is_valid():
         post = form.save();
         return HttpResponseRedirect(post.get_absolute_url())
@@ -246,7 +199,7 @@ def edit_profile_ctx(request):
 
 @login_required
 def edit_post_ctx(request, post_id):
-    from pybb.templatetags.pybb_extras import pybb_editable_by
+    from pybb.templatetags.pybb_tags import pybb_editable_by
 
     post = get_object_or_404(Post, pk=post_id)
 
@@ -278,7 +231,7 @@ def edit_post_ctx(request, post_id):
 
 @login_required
 def stick_topic(request, topic_id):
-    from pybb.templatetags.pybb_extras import pybb_moderated_by
+    from pybb.templatetags.pybb_tags import pybb_moderated_by
 
     topic = get_object_or_404(Topic, pk=topic_id)
     if pybb_moderated_by(topic, request.user):
@@ -290,7 +243,7 @@ def stick_topic(request, topic_id):
 
 @login_required
 def unstick_topic(request, topic_id):
-    from pybb.templatetags.pybb_extras import pybb_moderated_by
+    from pybb.templatetags.pybb_tags import pybb_moderated_by
 
     topic = get_object_or_404(Topic, pk=topic_id)
     if pybb_moderated_by(topic, request.user):
@@ -332,7 +285,7 @@ def delete_post_ctx(request, post_id):
 
 @login_required
 def close_topic(request, topic_id):
-    from pybb.templatetags.pybb_extras import pybb_moderated_by
+    from pybb.templatetags.pybb_tags import pybb_moderated_by
 
     topic = get_object_or_404(Topic, pk=topic_id)
     if pybb_moderated_by(topic, request.user):
@@ -345,7 +298,7 @@ def close_topic(request, topic_id):
 
 @login_required
 def open_topic(request, topic_id):
-    from pybb.templatetags.pybb_extras import pybb_moderated_by
+    from pybb.templatetags.pybb_tags import pybb_moderated_by
 
     topic = get_object_or_404(Topic, pk=topic_id)
     if pybb_moderated_by(topic, request.user):
@@ -358,7 +311,7 @@ def open_topic(request, topic_id):
 
 @login_required
 def merge_topics_ctx(request):
-    from pybb.templatetags.pybb_extras import pybb_moderated_by
+    from pybb.templatetags.pybb_tags import pybb_moderated_by
 
     topics_ids = request.GET.getlist('topic')
     topics = get_list_or_404(Topic, pk__in=topics_ids)
@@ -444,6 +397,7 @@ def post_ajax_preview(request):
     content = request.POST.get('content')
     markup = request.POST.get('markup')
 
+    print 'markup', markup
     if not markup in dict(MARKUP_CHOICES).keys():
         return {'error': 'Invalid markup'}
 
@@ -462,15 +416,15 @@ def post_ajax_preview(request):
             }
 
 
-users = render_to('pybb/users.html', users_ctx)
-merge_topics = render_to('pybb/merge_topics.html', merge_topics_ctx)
-delete_post = render_to('pybb/delete_post.html', delete_post_ctx)
-edit_post = render_to('pybb/edit_post.html', edit_post_ctx)
-edit_profile = render_to('pybb/edit_profile.html', edit_profile_ctx)
-user_topics = render_to('pybb/user_topics.html', user_topics_ctx)
-user = render_to('pybb/user.html', user_ctx)
-add_post = render_to('pybb/add_post.html', add_post_ctx)
-show_topic = render_to('pybb/topic.html', show_topic_ctx)
-show_forum = render_to('pybb/forum.html', show_forum_ctx)
-index = render_to('pybb/index.html', index_ctx)
-show_category = render_to('pybb/category.html', show_category_ctx)
+users = render_to('pybb/users.html')(users_ctx)
+merge_topics = render_to('pybb/merge_topics.html')(merge_topics_ctx)
+delete_post = render_to('pybb/delete_post.html')(delete_post_ctx)
+edit_post = render_to('pybb/edit_post.html')(edit_post_ctx)
+edit_profile = render_to('pybb/edit_profile.html')(edit_profile_ctx)
+user_topics = render_to('pybb/user_topics.html')(user_topics_ctx)
+user = render_to('pybb/user.html')(user_ctx)
+add_post = render_to('pybb/add_post.html')(add_post_ctx)
+show_topic = render_to('pybb/topic.html')(show_topic_ctx)
+show_forum = render_to('pybb/forum.html')(show_forum_ctx)
+index = render_to('pybb/index.html')(index_ctx)
+show_category = render_to('pybb/category.html')(show_category_ctx)
